@@ -1,5 +1,6 @@
 #!/usr/bin/env bash
+TRPROGRAM=$(printf $1 | tr - _)
 cat > $1/src/Makefile.am <<EOF
 bin_PROGRAMS = $1
-${1}_SOURCES = main.c
+${TRPROGRAM}_SOURCES = main.c
 EOF
